@@ -76,7 +76,7 @@ class PublishParamsChecker(LoggerMixin):
         # print(func)
         spec = inspect.getfullargspec(func)
         self.all_arg_name_set = set(spec.args)
-        print(spec.args)
+        # print(spec.args)
         if spec.defaults:
             len_deafult_args = len(spec.defaults)
             self.position_arg_name_list = spec.args[0: -len_deafult_args]
@@ -172,10 +172,10 @@ class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         with self._lock_for_count:
             self.count_per_minute += 1
             self.publish_msg_num_total += 1
-        if time.time() - self._current_time > 10:
-            self.logger.info(
-                f'10秒内推送了 {self.count_per_minute} 条消息,累计推送了 {self.publish_msg_num_total} 条消息到 {self._queue_name} 中')
-            self._init_count()
+            if time.time() - self._current_time > 10:
+                self.logger.info(
+                    f'10秒内推送了 {self.count_per_minute} 条消息,累计推送了 {self.publish_msg_num_total} 条消息到 {self._queue_name} 中')
+                self._init_count()
         return RedisAsyncResult(task_id)
 
     def push(self, *func_args, **func_kwargs):
